@@ -83,7 +83,7 @@ class ConnectResponse(KNXIPBodyResponse):
             + crd_to_knx()
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return (
             "<ConnectResponse "
