@@ -85,7 +85,7 @@ class SecureWrapper(KNXIPBody):
             + self.message_authentication_code
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return (
             f"<SecureWrapper "
