@@ -51,7 +51,7 @@ class TunnellingAck(KNXIPBodyResponse):
             )
         )
 
-    def __str__(self) -> str:
+    def __repr__(self) -> str:
         """Return object as readable string."""
         return (
             "<TunnellingAck "
