@@ -9,7 +9,7 @@ from __future__ import annotations
 from abc import abstractmethod
 from typing import TYPE_CHECKING, TypeVar, Union
 
-from xknx.dpt import DPTArray, DPTBase, DPTBinary, DPTNumeric
+from xknx.dpt import DPTArray, DPTBase, DPTBinary, DPTNumeric, DPTString
 from xknx.exceptions import ConversionError, CouldNotParseTelegram
 
 from .remote_value import AsyncCallbackType, GroupAddressesType, RemoteValue
@@ -24,6 +24,7 @@ class _RemoteValueGeneric(RemoteValue[DPTArray, ValueT]):
     """Abstraction for generic DPT types."""
 
     dpt_base_class: type[DPTBase]
+    _default_dpt_class: type[DPTBase] | None = None
 
     def __init__(
         self,
@@ -37,12 +38,16 @@ class _RemoteValueGeneric(RemoteValue[DPTArray, ValueT]):
         after_update_cb: AsyncCallbackType | None = None,
     ):
         """Initialize RemoteValueSensor class."""
-        if value_type is None:
-            raise ConversionError("no value type given", device_name=device_name)
-        _dpt_class = self.dpt_base_class.parse_transcoder(value_type)
+        _dpt_class = (
+            self.dpt_base_class.parse_transcoder(value_type)
+            if value_type is not None
+            else self._default_dpt_class
+        )
         if _dpt_class is None:
             raise ConversionError(
-                "invalid value type", value_type=value_type, device_name=device_name
+                f"invalid value type for base class {self.dpt_base_class.__name__}",
+                value_type=value_type,
+                device_name=device_name,
             )
         self.dpt_class = _dpt_class
         super().__init__(
@@ -103,3 +108,15 @@ class RemoteValueNumeric(_RemoteValueGeneric[Union[int, float]]):
     def from_knx(self, payload: DPTArray) -> int | float:
         """Convert current payload to value."""
         return self.dpt_class.from_knx(payload.value)
+
+
+class RemoteValueString(_RemoteValueGeneric[str]):
+    """Abstraction for string DPT types."""
+
+    dpt_base_class = DPTString
+    dpt_class: type[DPTString]
+    _default_dpt_class = DPTString
+
+    def from_knx(self, payload: DPTArray) -> str:
+        """Convert current payload to value."""
+        return self.dpt_class.from_knx(payload.value)
